Bug 1052573 - Generically whitelist memalign calls from anything under memory/. r?njn draft
authorMike Hommey <mh+mozilla@glandium.org>
Fri, 22 Sep 2017 08:57:23 +0900
changeset 668771 4084607826a3b3aee1e144b126752e99af213085
parent 668770 0436b6a009c67f87410809aabcff3bedb0c59cc5
child 668772 96e49ce5a98e44e957a497b64fde23a82e0c8156
push id81117
push userbmo:mh+mozilla@glandium.org
push dateFri, 22 Sep 2017 00:20:00 +0000
reviewersnjn
bugs1052573
milestone58.0a1
Bug 1052573 - Generically whitelist memalign calls from anything under memory/. r?njn
config/check_vanilla_allocations.py
--- a/config/check_vanilla_allocations.py
+++ b/config/check_vanilla_allocations.py
@@ -124,19 +124,19 @@ def main():
 
     for line in lines:
         m = re.search(alloc_fns_re, line)
         if m is None:
             continue
 
         filename = m.group(1)
 
-        # mozalloc contains calls to memalign. These are ok, so we whitelist
-        # them.
-        if "mozalloc" in filename:
+        # The memory allocator code contains calls to memalign. These are ok, so
+        # we whitelist them.
+        if "_memory_" in filename:
             continue
 
         fn = m.group(2)
         if filename == 'jsutil.o':
             jsutil_cpp.add(fn)
         else:
             # An allocation is present in a non-special file.  Fail!
             fail("'" + fn + "' present in " + filename)